GenerateEdgeWeights: Generates files of cluster:ligand:receptor:cluster edge...

Description Usage Arguments Value

View source: R/main_functions.R

Description

For a Seurat object, calculates all edge weights connecting source cell populations to ligands, ligands to receptors and receptors to target cell populations. Cell-ligand and receptor-cell edge weights are defined as the log2 fold-change difference in expression of the gene in that cell type relative to all other cell types in the Seurat object - as defined by the active identities. The ligand:receptor edge weights are assigned using protein:protein association scores from the STRING database.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
GenerateEdgeWeights(
  seurat.object,
  file.label,
  species,
  populations.use = NULL,
  pct.threshold = 0.1,
  use.string.offline = TRUE,
  string.dir = NULL,
  string.ver = NULL,
  string.receptors = NULL,
  string.ligands = NULL,
  string.input.map = NULL,
  string.evidence.class = "combined_score",
  verbose = FALSE
)

Arguments

seurat.object

a list of genes

file.label

a Seurat object with cluster identities

species

species of the experiment - currently includes 'human' and 'mouse'

populations.use

threshold of percentage of cells expressing the gene in a cluster for it to be considered expressed

pct.threshold

percentage of cells in a cluster expressing a gene for it to be considered

use.string.offline

whether to use packaged STRING scores (default) or retrieve online from STRINGdb

string.dir

directory for storing retrieved online STRING data (defaults to working directory)

string.ver

version of online STRING data-base to use. Not set by default.

string.receptors

a list of receptor names that STRING recognises (if cannot map defaults)

string.ligands

a list of ligand names that STRING recegnises (if cannot map defaults)

string.input.map

named vector of STRING-compatable gene symbols with names corresponding to genes in dataset

string.evidence.class

what STRING evidence class to use. Defaults to 'combined_score'. Alternatives are: "neighborhood", "neighborhood_transferred", "fusion", "cooccurence", "homology", "coexpression", "coexpression_transferred", "experiments", "experiments_transferred", "database", "database_transferred", "textmining" and "textmining_transferred"

verbose

whether to print additional information about run (default: FALSE)

Value

NULL - results written to file


VCCRI/scTalk documentation built on June 5, 2021, 6:35 a.m.