GenerateNetworkPaths: Generates files of weighted source:ligand:receptor:target...

Description Usage Arguments Value

View source: R/main_functions.R

Description

Uses files generated with the GenerateEdgeWeights function to generate weighted paths connecting source(clusters):ligands:receptors:target(clusters). Paths are weighted by summing the three edges - source:ligand, ligand:receptor and receptor:target. Paths passing a minimum weight threshold are retained. For following permuation testing, a 'background' set of paths without thresholding are also written out.

Usage

1
2
3
4
5
6
GenerateNetworkPaths(
  file.label,
  populations.use = NULL,
  min.weight = 1.5,
  ncores = 1
)

Arguments

file.label

a list of genes

populations.use

the cell populations to use (default is all)

min.weight

minimum weight for retaining a path

ncores

number of cores for parallelisation

Value

NULL - results written to file


VCCRI/scTalk documentation built on June 5, 2021, 6:35 a.m.