PlotTopLigands: Plot a bar graph of the top ligands

Description Usage Arguments Value Examples

View source: R/plotting.R

Description

Plot a bar graph of the top ligands

Usage

1
2
3
4
5
6
7
8
PlotTopLigands(
  input.file,
  cell.identity,
  col.use = "#757575",
  min.weight = 2,
  max.plot.num = 15,
  title.use = NULL
)

Arguments

input.file

a table of source:ligand:receptor:target paths.

cell.identity

the name of a cell population/cluster to use

col.use

optional paramater to set colour of the bar graph.

min.weight

minimum weight for including paths in the top ligand calculations.

max.plot.num

the maximum number of ligands to plot

Value

a ggplot2 object.

Examples

1
2
3
4
## Not run: 
PlotTopLigands(path.table = example.table, cell.identity = '1')

## End(Not run)

VCCRI/scTalk documentation built on June 5, 2021, 6:35 a.m.