calculate_cluster_specific_expression: Calculate expression metrics across clusters for a set of...

Description Usage Arguments Value

View source: R/graph_internal.R

Description

For a provided set of genes, go through each cluster and calculate the average log2-expression of each gene in the cluster, the percentage of cells expressing the gene in the cluster and the log2 FC difference between the cluster and the remaining clusters. Return a data-frame of the results

Usage

1
2
3
4
5
6
7
calculate_cluster_specific_expression(
  geneList,
  seurat.object,
  exp.threshold = 0,
  threshold = 0.1,
  cluster.set = NULL
)

Arguments

geneList

a list of genes

exp.threshold

expression threshold for considering a gene expressed in a cell

threshold

Threshold of percentage of cells expressing the gene in a cluster for it to be considered expressed

seurat.obect

a Seurat object with cluster identities

option

set of clusters (default: all in the Seurat object)

Value

a data-frame of results


VCCRI/scTalk documentation built on June 5, 2021, 6:35 a.m.