get_gene_pair_expression_values: Identify expression of ligands/receptors among clusters

Description Usage Arguments Value

View source: R/graph_internal.R

Description

For a set of ligand-receptor pairs, evaluates whether one of the gene pairs is expressed for each of the clusters and builds a table mapping each ligand-expressing cluster to each corresponding receptor-expressing cluster.

Usage

1
2
3
4
5
6
get_gene_pair_expression_values(
  ligand.receptor.pairs,
  mapping.table,
  cluster.names,
  gene.de.results
)

Arguments

ligand.receptor.pairs

table of ligand-receptor pairs

mapping.table

human:mouse gene ID mappings

cluster.names

set of cluster IDs to use

gene.de.results

table of expression values produced by calculate_cluster_specific_expression

Value

a data-frame of results


VCCRI/scTalk documentation built on June 5, 2021, 6:35 a.m.