get_weighted_paths: Determine weights paths between query source and target...

Description Usage Arguments Value Examples

View source: R/graph_internal.R

Description

Given a table of weights for source:ligands, ligands:receptors and receptors:targets and a query source and target population, build a weighted, directed graph (using the igraph package) and pull out summed paths between the query source and target populations. Retain paths above a user-provided minimum weight.

Usage

1
2
3
4
5
6
7
get_weighted_paths(
  edge.weight.table,
  source.population,
  target.population,
  min.weight = 1.5,
  print.num.connections = FALSE
)

Arguments

edge.weight.table

a table of edges and weights for building the source:ligand:receptor:target graph

source.population

source (ligand-expressing) population

target.population

target (receptor-expressing) population

min.weight

minimum weight for retaining a source:target path (deafult is 1.5)

print.num.connections

whether to print the number of paths passing the min weight threshold (False by default)

Value

a vector of source:target path weights

Examples

1
2
3
4
## Not run: 
getWeightedPaths(edge.weight.table, source.population, target.population)

## End(Not run)

VCCRI/scTalk documentation built on June 5, 2021, 6:35 a.m.