Description Usage Arguments Value
View source: R/main_functions.R
Uses files generated with the GenerateEdgeWeights function to generate weighted paths connecting source(clusters):ligands:receptors:target(clusters). Paths are weighted by summing the three edges - source:ligand, ligand:receptor and receptor:target. Paths passing a minimum weight threshold are retained. For following permuation testing, a 'background' set of paths without thresholding are also written out.
1 2 3 4 5 6 | GenerateNetworkPaths(
file.label,
populations.use = NULL,
min.weight = 1.5,
ncores = 1
)
|
file.label |
a list of genes |
populations.use |
the cell populations to use (default is all) |
min.weight |
minimum weight for retaining a path |
ncores |
number of cores for parallelisation |
NULL - results written to file
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.