Description Usage Arguments Value
View source: R/graph_internal.R
For a set of ligand-receptor pairs, evaluates whether one of the gene pairs is expressed for each of the clusters and builds a table mapping each ligand-expressing cluster to each corresponding receptor-expressing cluster.
1 2 3 4 5 6 | get_gene_pair_expression_values(
ligand.receptor.pairs,
mapping.table,
cluster.names,
gene.de.results
)
|
ligand.receptor.pairs |
table of ligand-receptor pairs |
mapping.table |
human:mouse gene ID mappings |
cluster.names |
set of cluster IDs to use |
gene.de.results |
table of expression values produced by calculate_cluster_specific_expression |
a data-frame of results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.