Description Usage Arguments Value Examples
View source: R/graph_internal.R
Generates a randomisation of the network by shuffling the source:ligand and receptor:target weights, which are dervied from fold-change expression. The ligand:receptor weights derived from STRINGdb remain unshuffled. The weights are then summed to represent randomised source:target path weights.
1 | randomise_FC_weights(ppi.weights, cluster.ligand.table, receptor.cluster.table)
|
ppi.weights |
a vector of ligands |
cluster.ligand.table |
a vector of receptors |
receptor.cluster.table |
species to use - either mouse (default) or human |
a vector of source:target path weights
1 2 3 4 | ## Not run:
RandomiseFCWeights(ppi.weights, cluster.ligand.table, receptor.cluster.table)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.