Description Usage Arguments Value Examples
Takes as input a ggraph object containing a tree graph with 1 or more source nodes at the root connecting to targets in the leaf nodes with connecting ligands and receptors as intermediates. Rescales the X-coordinates of the nodes to ensure an even spacing. Rescales according to a reference row - ligands by default, but probably works best when specified as the row with largets number of nodes. Can select rows to rescale, though all are done by default.
1 2 3 4 5 | rescale_node_coordinates(
graph,
scale.by = "Ligand",
do.update = c("Source", "Ligand", "Receptor", "Target")
)
|
graph |
a ggraph object containing a tree graph. |
scale.by |
a reference row to scale to. Ligand by default. |
do.update |
select graph rows to updates. All by default. |
a ggraph object with node X-coordinates rescaled.
1 2 3 4 | ## Not run:
rescale_target_node_coordinates(tree.graph)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.